gpmp is mainly developed and maintained by:

 * VAZQUEZ Emmanuel

The following people have helped develop the package in various ways
(from providing ideas and bug reports to actually contributing code):

 * ...
